@@ -324,7 +324,8 @@ xnee_handle_xinput_event(xnee_data * xd,
 int 
 xnee_handle_xinput_event_human(xnee_data * xd, 
 			       int event_type, 
-			       XRecordDatum *xrec_data)
+			       XRecordDatum *xrec_data,
+			       Time server_time)
 {
   static saved_xinput_event sxe;
   FILE *out ;
@@ -421,9 +422,10 @@ xnee_handle_xinput_event_human(xnee_data * xd,
 	    }
 	  
 	  XNEE_XINPUT_PRINT_MASTER_OR_SLAVE(xd, e->deviceid, out);
-	  fprintf (out, ",XInput Event=%s  Number=%d %s",
-		   xd->xi_data.xi_devices[e->deviceid].name,		  
-		   sxe.type);
+	  (void)xd->data_fp (xd->out_file,
+			     ",XInput Event=%s  Number=%d ",
+			     xd->xi_data.xi_devices[e->deviceid].name,
+			     sxe.type);
 	  (void)xd->data_fp (xd->out_file,"\n");
 
 	  sxe.x = 0;
@@ -539,9 +541,11 @@ xnee_xinput_add_devices(xnee_data *xd)
   return XNEE_OK;
 }
 	  
+int
 xnee_handle_xinput_event_human(xnee_data * xd, 
 			       int event_type, 
-			       XRecordDatum *xrec_data)
+			       XRecordDatum *xrec_data,
+			       Time server_time)
 {
   return XNEE_OK;
 }
